BasePlayerCreate

Struct BasePlayerCreate 

pub struct BasePlayerCreate {
    pub players_battle_categories_ids: Option<HashMap<u64, (u8, u32)>>,
    pub battle_level: u8,
    pub battle_category_id: u8,
    pub is_mouse_enabled: bool,
    pub matchmaker_type: u8,
    pub camouflage_slot: u8,
    pub average_mm_ratings: Option<Vec<Option<f64>>>,
    pub player_wait_times: Option<HashMap<u64, f64>>,
    pub account_database_ids: Option<Vec<u64>>,
    pub turbo_battles_statistics: Option<TurboBattlesStatistics>,
}

Fields

players_battle_categories_ids: Option<HashMap<u64, (u8, u32)>>battle_level: u8battle_category_id: u8is_mouse_enabled: boolmatchmaker_type: u8camouflage_slot: u8average_mm_ratings: Option<Vec<Option<f64>>>

Average team ratings for rating battles.

Contains

  • Some 2-vector, if the attribute is present in the replay. Each element represents one team:
    • Some rating, if known
    • None, if the average rating is unknown (all the players are calibrating)
  • None, if the attribute is missing in the replay
player_wait_times: Option<HashMap<u64, f64>>account_database_ids: Option<Vec<u64>>turbo_battles_statistics: Option<TurboBattlesStatistics>