Packet

Struct Packet 

pub struct Packet {
    pub clock_secs: f32,
    pub payload: Payload,
}
«Packet» is a single traffic message in a replay, packets tell us what is going on during the battle.

Fields

clock_secs: f32

Replay time, starting from zero.

payload: Payload

Parsed packet payload.

Implementations

Source

impl Packet

pub fn from_reader(reader: &mut impl Read) -> Result<Option<Self>>

Parse next packet from the reader.

Returns

Parsed packet, or None, when no packets are left.