RoomType

Enum RoomType 

pub enum RoomType {
    Any = 0,
    Regular = 1,
    TrainingRoom = 2,
    Tournament = 4,
    QuickTournament = 5,
    Rating = 7,
    MadGames = 8,
    RealisticBattles = 22,
    Uprising = 23,
    GravityMode = 24,
    Skirmish = 25,
    BurningGames = 26,
}

Variants



Any = 0



Regular = 1



TrainingRoom = 2



Tournament = 4



QuickTournament = 5



Rating = 7



MadGames = 8



RealisticBattles = 22



Uprising = 23



GravityMode = 24



Skirmish = 25



BurningGames = 26

Implementations

Source

impl RoomType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of RoomType.

pub fn from_i32(value: i32) -> Option<RoomType>

Converts an i32 to a RoomType, or None if value is not a valid variant.