pub struct Packet {
pub clock_secs: f32,
pub payload: Payload,
}Expand description
«Packet» is a single traffic message in a replay, packets tell us what is going on during the battle.
Fields
clock_secs: f32Replay time, starting from zero.
payload: PayloadParsed packet payload.
Implementations